@@ -108,6 +108,7 @@ class DashboardView(TemplateView):  # pylint: disable=missing-permission-require
         )
         test_plans_disable_count = test_plans.filter(is_active=False).count()
 
+        # pylint: disable=unsupported-binary-operation
         test_runs = (
             TestRun.objects.filter(
                 Q(manager=self.request.user)
@@ -178,7 +179,7 @@ class InitDBView(TemplateView):  # pylint: disable=missing-permission-required
 
     template_name = "initdb.html"
 
-    def post(self, request):
+    def post(self, request):  # pylint: disable=no-self-use
         # Default production installation
         manage_path = "/Kiwi/manage.py"
         if not os.path.exists(manage_path):
