@@ -54,11 +54,13 @@ class AzureBoardsAPI:
             f"{self.base_url}wit/workItems/{issue_id}/"
             f"comments/{comment_id}{self.api_version}-preview.3"
         )
-        return requests.request("DELETE", url, headers=headers, auth=self.auth)
+        return requests.request(
+            "DELETE", url, headers=headers, auth=self.auth, timeout=30
+        )
 
     @staticmethod
     def _request(method, url, **kwargs):
-        return requests.request(method, url, **kwargs).json()
+        return requests.request(method, url, timeout=30, **kwargs).json()
 
 
 class AzureThread(IntegrationThread):
@@ -95,7 +97,7 @@ class AzureBoards(IssueTrackerType):
     def is_adding_testcase_to_issue_disabled(self):
         return not (self.bug_system.base_url and self.bug_system.api_password)
 
-    def report_issue_from_testexecution(self, execution, user):
+    def _report_issue(self, execution, user):
         """
         AzureBoards creates the Work Item with Title
         """
@@ -114,7 +116,7 @@ class AzureBoards(IssueTrackerType):
                 "op": "replace",
                 "path": "/fields/System.Description",
                 "from": "null",
-                "value": markdown2html(self._report_comment(execution)),
+                "value": markdown2html(self._report_comment(execution, user)),
             }
         ]
 
@@ -132,7 +134,7 @@ class AzureBoards(IssueTrackerType):
                 is_defect=True,
             )
 
-            return issue_url
+            return (issue, issue_url)
         except Exception:  # pylint: disable=broad-except
             # something above didn't work so return a link for manually
             # entering issue details with info pre-filled
@@ -140,7 +142,7 @@ class AzureBoards(IssueTrackerType):
             if not url.endswith("/"):
                 url += "/"
 
-            return url + "_workitems/create/Issue"
+            return (None, url + "_workitems/create/Issue")
 
     def details(self, url):
         """
