@@ -54,8 +54,8 @@ class BitBucketAPI:
     @staticmethod
     def _request(method, url, **kwargs):
         if method == "DELETE":
-            return requests.request(method, url, **kwargs)
-        return requests.request(method, url, **kwargs).json()
+            return requests.request(method, url, timeout=30, **kwargs)
+        return requests.request(method, url, timeout=30, **kwargs).json()
 
     @staticmethod
     def _construct_endpoint_url(api_version, url):
@@ -119,7 +119,7 @@ class BitBucket(IssueTrackerType):
             and self.bug_system.api_password
         )
 
-    def report_issue_from_testexecution(self, execution, user):
+    def _report_issue(self, execution, user):
         """
         BitBucket creates the Issue with Title and Description
         """
@@ -128,7 +128,9 @@ class BitBucket(IssueTrackerType):
             "title": f"Failed test: {execution.case.summary}",
             "kind": "bug",
             "priority": "major",
-            "content": {"raw": self._report_comment(execution).replace("\n", "\r\n")},
+            "content": {
+                "raw": self._report_comment(execution, user).replace("\n", "\r\n")
+            },
         }
 
         try:
@@ -142,7 +144,7 @@ class BitBucket(IssueTrackerType):
                 is_defect=True,
             )
 
-            return issue_url
+            return (issue, issue_url)
         except Exception:  # pylint: disable=broad-except
             # something above didn't work so return a link for manually
             # entering issue details with info pre-filled
@@ -150,7 +152,7 @@ class BitBucket(IssueTrackerType):
             if not url.endswith("/"):
                 url += "/"
 
-            return url + "issues/new"
+            return (None, url + "issues/new")
 
     def details(self, url):
         """
