@@ -1,4 +1,4 @@
-# Copyright (c) 2019-2021 Alexander Todorov <atodorov@MrSenko.com>
+# Copyright (c) 2019-2022 Alexander Todorov <atodorov@MrSenko.com>
 
 # Licensed under the GPL 2.0: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 
@@ -73,7 +73,7 @@ class KiwiTCMS(IssueTrackerType):
         for execution in executions:
             bug.executions.add(execution)
 
-    def report_issue_from_testexecution(self, execution, user):
+    def _report_issue(self, execution, user):
         """
         Create the new bug using internal API instead of
         going through the RPC layer and return its URL
@@ -84,7 +84,7 @@ class KiwiTCMS(IssueTrackerType):
             "product": execution.run.plan.product,
             "version": execution.run.plan.product_version,
             "build": execution.build,
-            "text": self._report_comment(execution),
+            "text": self._report_comment(execution, user),
             "_execution": execution,
         }
 
@@ -100,7 +100,7 @@ class KiwiTCMS(IssueTrackerType):
             is_defect=True,
         )
 
-        return bug.get_full_url()
+        return (bug, bug.get_full_url())
 
     @classmethod
     def bug_id_from_url(cls, url):
