@@ -2,7 +2,7 @@ from django import forms
 
 from tcms.core.forms.fields import UserField
 from tcms.rpc.api.forms import UpdateModelFormMixin
-from tcms.testcases.models import TestCase
+from tcms.testcases.models import Category, TestCase
 
 
 class NewForm(forms.ModelForm):
@@ -24,3 +24,9 @@ class UpdateForm(UpdateModelFormMixin, forms.ModelForm):
     default_tester = UserField()
     author = UserField()
     reviewer = UserField()
+
+
+class CategoryForm(forms.ModelForm):
+    class Meta:
+        model = Category
+        fields = "__all__"
