@@ -1,5 +1,8 @@
 # -*- coding: utf-8 -*-
 
+from datetime import timedelta
+
+from django.db.models.functions import Coalesce
 from django.forms import EmailField, ValidationError
 from django.forms.models import model_to_dict
 from modernrpc.core import REQUEST_KEY, rpc_method
@@ -10,7 +13,7 @@ from tcms.management.models import Component, Tag
 from tcms.rpc import utils
 from tcms.rpc.api.forms.testcase import NewForm, UpdateForm
 from tcms.rpc.decorators import permissions_required
-from tcms.testcases.models import TestCase, TestCasePlan
+from tcms.testcases.models import Property, TestCase, TestCasePlan
 
 __all__ = (
     "create",
@@ -31,6 +34,9 @@ __all__ = (
     "remove_tag",
     "add_attachment",
     "list_attachments",
+    "properties",
+    "remove_property",
+    "add_property",
 )
 
 
@@ -186,7 +192,7 @@ def add_tag(case_id, tag, **kwargs):
         :type case_id: int
         :param tag: Tag name to add
         :type tag: str
-        :param kwargs: Dict providing access to the current request, protocol
+        :param \\**kwargs: Dict providing access to the current request, protocol,
                 entry point name and handler instance from the rpc method
         :raises PermissionDenied: if missing *testcases.add_testcasetag* permission
         :raises TestCase.DoesNotExist: if object specified by PK doesn't exist
@@ -226,7 +232,7 @@ def create(values, **kwargs):
 
         :param values: Field values for :class:`tcms.testcases.models.TestCase`
         :type values: dict
-        :param kwargs: Dict providing access to the current request, protocol
+        :param \\**kwargs: Dict providing access to the current request, protocol,
                 entry point name and handler instance from the rpc method
         :return: Serialized :class:`tcms.testcases.models.TestCase` object
         :rtype: dict
@@ -255,6 +261,8 @@ def create(values, **kwargs):
         result = model_to_dict(test_case, exclude=["component", "plan", "tag"])
         # b/c date is added in the DB layer and model_to_dict() doesn't return it
         result["create_date"] = test_case.create_date
+        result["setup_duration"] = str(result["setup_duration"])
+        result["testing_duration"] = str(result["testing_duration"])
         return result
 
     raise ValueError(form_errors_to_list(form))
@@ -277,8 +285,12 @@ def filter(query=None):  # pylint: disable=redefined-builtin
     if query is None:
         query = {}
 
-    return list(
-        TestCase.objects.filter(**query)
+    qs = (
+        TestCase.objects.annotate(
+            expected_duration=Coalesce("setup_duration", timedelta(0))
+            + Coalesce("testing_duration", timedelta(0))
+        )
+        .filter(**query)
         .values(
             "id",
             "create_date",
@@ -302,10 +314,15 @@ def filter(query=None):  # pylint: disable=redefined-builtin
             "default_tester__username",
             "reviewer",
             "reviewer__username",
+            "setup_duration",
+            "testing_duration",
+            "expected_duration",
         )
         .distinct()
     )
 
+    return list(qs)
+
 
 @permissions_required("testcases.view_testcase")
 @rpc_method(name="TestCase.history")
@@ -395,6 +412,8 @@ def update(case_id, values):
         result["reviewer__username"] = (
             test_case.reviewer.username if test_case.reviewer else None
         )
+        result["setup_duration"] = str(result["setup_duration"])
+        result["testing_duration"] = str(result["testing_duration"])
 
         return result
 
@@ -435,7 +454,7 @@ def list_attachments(case_id, **kwargs):
 
         :param case_id: PK of TestCase to inspect
         :type case_id: int
-        :param kwargs: Dict providing access to the current request, protocol
+        :param \\**kwargs: Dict providing access to the current request, protocol,
                 entry point name and handler instance from the rpc method
         :return: A list containing information and download URLs for attachements
         :rtype: list
@@ -460,7 +479,7 @@ def add_attachment(case_id, filename, b64content, **kwargs):
         :type filename: str
         :param b64content: Base64 encoded content
         :type b64content: str
-        :param kwargs: Dict providing access to the current request, protocol
+        :param \\**kwargs: Dict providing access to the current request, protocol,
                 entry point name and handler instance from the rpc method
     """
     utils.add_attachment(
@@ -484,7 +503,7 @@ def add_comment(case_id, comment, **kwargs):
         :type case_id: int
         :param comment: The text to add as a comment
         :type comment: str
-        :param kwargs: Dict providing access to the current request, protocol
+        :param \\**kwargs: Dict providing access to the current request, protocol,
                 entry point name and handler instance from the rpc method
         :return: Serialized :class:`django_comments.models.Comment` object
         :rtype: dict
@@ -547,3 +566,70 @@ def comments(case_id):
         result.append(model_to_dict(comment))
 
     return result
+
+
+@permissions_required("testcases.view_property")
+@rpc_method(name="TestCase.properties")
+def properties(query=None):
+    """
+    .. function:: TestCase.properties(query)
+
+        Return all properties for the specified test case(s).
+
+        :param query: Field lookups for :class:`tcms.testcases.models.Property`
+        :type query: dict
+        :return: Serialized list of :class:`tcms.testcases.models.Property` objects.
+        :rtype: list(dict)
+        :raises PermissionDenied: if missing *testcases.view_property* permission
+    """
+    if query is None:
+        query = {}
+
+    return list(
+        Property.objects.filter(**query)
+        .values(
+            "id",
+            "case",
+            "name",
+            "value",
+        )
+        .order_by("case", "name", "value")
+        .distinct()
+    )
+
+
+@permissions_required("testcases.delete_property")
+@rpc_method(name="TestCase.remove_property")
+def remove_property(query):
+    """
+    .. function:: TestCase.remove_property(query)
+
+        Remove selected properties.
+
+        :param query: Field lookups for :class:`tcms.testcases.models.Property`
+        :type query: dict
+        :raises PermissionDenied: if missing *testcases.delete_property* permission
+    """
+    Property.objects.filter(**query).delete()
+
+
+@permissions_required("testcases.add_property")
+@rpc_method(name="TestCase.add_property")
+def add_property(case_id, name, value):
+    """
+    .. function:: TestCase.add_property(case_id, name, value)
+
+        Add property to test case! Duplicates are skipped without errors.
+
+        :param case_id: Primary key for :class:`tcms.testcases.models.TestCase`
+        :type case_id: int
+        :param name: Name of the property
+        :type name: str
+        :param value: Value of the property
+        :type value: str
+        :return: Serialized :class:`tcms.testcases.models.Property` object.
+        :rtype: dict
+        :raises PermissionDenied: if missing *testcases.add_property* permission
+    """
+    prop, _ = Property.objects.get_or_create(case_id=case_id, name=name, value=value)
+    return model_to_dict(prop)
