@@ -2,12 +2,12 @@
 
 from modernrpc.core import rpc_method
 
-from tcms.testcases.models import TestCaseStatus
 from tcms.rpc.decorators import permissions_required
+from tcms.testcases.models import TestCaseStatus
 
 
-@permissions_required('testcases.view_testcasestatus')
-@rpc_method(name='TestCaseStatus.filter')
+@permissions_required("testcases.view_testcasestatus")
+@rpc_method(name="TestCaseStatus.filter")
 def filter(query):  # pylint: disable=redefined-builtin
     """
     .. function:: RPC TestCaseStatus.filter(query)
@@ -19,4 +19,8 @@ def filter(query):  # pylint: disable=redefined-builtin
         :return: Serialized list of :class:`tcms.testcases.models.TestCaseStatus` objects
         :rtype: list(dict)
     """
-    return TestCaseStatus.to_xmlrpc(query)
+    return list(
+        TestCaseStatus.objects.filter(**query)
+        .values("id", "name", "description", "is_confirmed")
+        .distinct()
+    )
