@@ -7,5 +7,5 @@ from django.urls import re_path
 from . import views
 
 urlpatterns = [
-    re_path(r'^example/$', views.Example.as_view(), name='a_fake_plugin-example_view'),
+    re_path(r"^example/$", views.Example.as_view(), name="a_fake_plugin-example_view"),
 ]
