@@ -189,7 +189,7 @@ function getTestCaseRowContent (rowContent, testCase, permissions) {
   let automatedClassToRemove = 'fa-cog'
 
   if (testCase.is_automated) {
-    automatedClassToRemove = 'fa-thumbs-up'
+    automatedClassToRemove = 'fa-hand-paper-o'
   }
 
   automationIndicationElement.parent().attr(
@@ -626,7 +626,8 @@ function toolbarEvents (testPlanId, permissions) {
       }
     }
 
-    window.location.assign(`/runs/new?p=${testPlanId}&c=${selectedTestCases.join('&c=')}`)
+    const newTestRunUrl = $('#test_plan_pk').data('new-testrun-url')
+    window.location.assign(`${newTestRunUrl}?c=${selectedTestCases.join('&c=')}`)
     return false
   })
 }
